#
# spec file for package ucommon
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2008, 2009 David Sugar, Tycho Softworks.
# This file is free software; as a special exception the author gives
# unlimited permission to copy and/or distribute it, with or without
# modifications, as long as this notice is preserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ucommon
Version:        6.6.0
Release:        4.1
%define lname	libucommon7
Summary:        Runtime library for portable C++ threading and sockets
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Url:            http://www.gnu.org/software/commoncpp

#Git-Clone:	git://github.com/dyfet/ucommon
Source:         http://ftp.gnu.org/gnu/commoncpp/%name-%version.tar.gz
Source2:        http://ftp.gnu.org/gnu/commoncpp/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz-gd
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(openssl)
# Added for 13.1
Obsoletes:      %name-bin < %version-%release
Provides:       %name-bin = %version-%release

%description
GNU uCommon C++ is a lightweight library to facilitate using C++
design patterns even for very deeply embedded applications, such as
for systems using uClibc along with POSIX threading support.

This subpackage contains a collection of command line tools that use
various aspects of the ucommon library. Some may be needed to prepare
files or for development of applications.

%package -n %lname
Summary:        GNU uCommon Runtime library for portable C++ threading and sockets
Group:          System/Libraries

%description -n %lname
GNU uCommon C++ is a lightweight library to facilitate using C++
design patterns even for very deeply embedded applications, such as
for systems using uClibc along with POSIX threading support. For this
reason, uCommon disables language features that consume memory or
introduce runtime overhead. uCommon introduces some design patterns
from Objective-C, such as reference counted objects, memory pools,
and smart pointers. uCommon introduces some new concepts for handling
of thread locking and synchronization.

%package devel
Summary:        Headers for building ucommon applications
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libopenssl-devel

%description devel
This package provides header and support files needed for building
applications that use the uCommon library and frameworks.

%package doc
Summary:        Generated class documentation for ucommon
Group:          Documentation
%if 0%{?suse_version} >= 1230
BuildArch:      noarch
%endif

%description doc
Generated class documentation for GNU uCommon library from header files,
html browsable.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
chmod a+x "%buildroot/%_bindir"/*-config

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS README NEWS SUPPORT ChangeLog
%_bindir/args
%_bindir/car
%_bindir/keywait
%_bindir/scrub-files
%_bindir/mdsum
%_bindir/pdetach
%_bindir/sockaddr
%_bindir/zerofill
%_mandir/man1/args.*
%_mandir/man1/scrub-files.*
%_mandir/man1/mdsum.*
%_mandir/man1/pdetach.1*
%_mandir/man1/zerofill.*
%_mandir/man1/sockaddr.*
%_mandir/man1/car.*
%_mandir/man1/keywait.*

%files -n %lname
%defattr(-,root,root)
%doc COPYING COPYING.LESSER COPYRIGHT
%_libdir/libucommon.so.7*
%_libdir/libusecure.so.7*
%_libdir/libcommoncpp.so.7*

%files devel
%defattr(-,root,root)
%_libdir/*.so
%_includedir/ucommon/
%_includedir/commoncpp/
%_datadir/ucommon/
%_libdir/pkgconfig/*.pc
%_bindir/ucommon-config
%_bindir/commoncpp-config
%_mandir/man1/ucommon-config.*
%_mandir/man1/commoncpp-config.*

%changelog
* Wed Sep  9 2015 mpluskal@suse.com
- Update to 6.6.0
  * introduced rsa key support
  * expanded hmac support
  * expanded digests for sha256 and 384
  * reword of common digest code
  * improved nullptr clang support
  * remove clang forced c++11 from build
  * check for openssl rsa support
  * port types for 7.0 migration
  * socket addresses for typeref
  * further c++11 header fixes
  * removed old ssl demo app
* Sun Aug 30 2015 mpluskal@suse.com
- Update to 6.5.7
  * improved c++11 support
  * mapped pointer introduced
  * fixed is usage
  * improved mapref remove
- Changes from 6.5.5 to 6.5.6
  * simplified arrayref
  * added listref
  * map iterators thru locked instances
  * type standardization
  * socket address type
- Changes from 6.5.4 to 6.5.5
  * more portable nullptr support
  * thread-safe mapref class
  * some typeref convenience types
  * bit operations on byterefs
- Changes from 6.5.3 to 6.5.4
  * secure string and key management types
  * better cleanup of secure objects
  * file i/o for heap temporary
- Changes from 6.5.2 to 6.5.3
  * arrayref now uses ConditionalAccess, fix for Conditional
- Changes from 6.5.1 to 6.5.2
  * memory management cleanup and mingw32 support for native
    conditionals
  * new methodology of having getaddrinfo allocate memory
  * introduction of queueref and stackref; arrayref becomes
    useful typeref concatenation operators
* Thu Aug 13 2015 mpluskal@suse.com
- Update to 6.5.1
  * thread shared references added
- Changes from 6.4.4 to 6.5.0
  * typeref expanded
  * arrayref introduced
  * nullptr and other c++ modernizations
  * clang now defaulted to c++11
  * minimum native windows now requires conditionals
  * mingw has to use win32 pthread support
  * somewhat more usable heap temporary templates
- Changes from 6.4.3 to 6.4.4
  * additional typeref operators
- Changes from 6.4.2 to 6.4.3
  * fix for broken windows setuid macro
-Changes from 6.4.1 to 6.4.2
  * solaris related cmake fixes
  * cleanup of test build and osx fixes
- Changes from 6.4.0 to 6.4.1
  * keyfile fixed constructor issue
- Changes from 6.3.6 to 6.4.0
  * new typeref system for immutable atomic reference counted
    objects
  * heap management objects support moving heap through
    assignment
  * extended unit tests for typeref system
  * improved openbsd support
  * atomics enabled by default
- Changes from 6.3.5 to 6.3.6
  * code cleanup
  * simulate option for scrub
  * set newline style for cmake genorated files
- Changes from 6.3.4 to 6.3.5
  * general code cleanup
  * some build fixes
- Changes from 6.3.3 to 6.3.4
  * improved atomics support
  * configure atomics default matches cmake default
  * general code cleanup
  * more casting operations and cast fixups
  * polymorphic casting support & rtti detection
  * enclose random value templates in Random
  * improved rng support
- Changes from 6.3.2 to 6.3.3
  * improved cipher key management
  * b64 support improved and string hex conversions
  * simplified digest functions
  * some solaris fixes
* Sun Mar 29 2015 jengelh@inai.de
- Update to new upstream release 6.3.1
  * Build system updates only
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 6.3.0
  * remove legacy cmodel support
  * modernize library usage
  * simplify autoconf and cmake
  * introduce sysruntime
  * cleanup memory operators
* Sun Aug 10 2014 jengelh@inai.de
- Update to new upstream release 6.1.10
  * Fix a memory leak in DateTime ctor
  * Socket::address: allow printing to std::ostream
  * Socket::address: use in_port_t for port numbers
  * Socket::join, ::drop: allow to set interface index for IPv6
* Sat Jun 28 2014 jengelh@inai.de
- Update to new upstream release 6.1.8
  * A number of changes to Socket::address.
* Sun May  4 2014 dyfet@gnutelephony.org
- Update to new upstream release 6.1.3
  * A number of memory corruption issues fixed & improved cmake
  build support in this package.  A new keywait utility was
  added.  Exception behavior standardized for commoncpp.  Many
  changes to improve commoncpp legacy support.  Fixed default
  Semaphore constructor and default Semaphore behavior.
- Proposed method to add doc support back to spec.
- Other small improvements in spec, including those made possible
  with better cmake support upstream.
* Tue Oct  1 2013 jengelh@inai.de
- Update to new upstream release 6.0.7
  * Small but essential fixes in the fsys class. Fixes for other
  small socket address validation assignment operations that
  risked security.
* Thu Jun 13 2013 jengelh@inai.de
- Update to new upstream release 6.0.5
  * A new version 6 API. A complete refactor of most core classes for
  greater consistency and simplicity. Many depreciated methods and
  conventions have been removed.
- Implement shlib package naming guideline. Signature verification.
* Mon Dec 26 2011 jengelh@medozas.de
- Remove redundant tags/sections
* Tue Nov 29 2011 idoenmez@suse.de
- Use upstream tarball
* Tue Nov 29 2011 ro@suse.de
- define LIB_SUFFIX for other lib64 platforms
* Sat Jul 30 2011 Werner.Dittmann@t-online.de
- First version of GNU uCommon as standard package
  The changelog file in the source package contains the the full history
  of GNU uCommon. Changes to GNU uCommon that happen after it becomes
  a standard package will be recorded in ucommon.changes file as well.
